@@ -40,6 +40,23 @@ from nwp500.encoding import (
     encode_season_bitfield,
     encode_week_bitfield,
 )
+from nwp500.enums import (
+    CommandCode,
+    CurrentOperationMode,
+    DhwOperationSetting,
+    DREvent,
+    ErrorCode,
+    FilterChange,
+    HeatSource,
+    OnOffFlag,
+    Operation,
+    RecirculationMode,
+    TemperatureType,
+    TempFormulaType,
+    TouRateType,
+    TouWeekType,
+    UnitType,
+)
 from nwp500.events import (
     EventEmitter,
     EventListener,
@@ -66,12 +83,10 @@ from nwp500.exceptions import (
     ValidationError,
 )
 from nwp500.models import (
-    CurrentOperationMode,
     Device,
     DeviceFeature,
     DeviceInfo,
     DeviceStatus,
-    DhwOperationSetting,
     EnergyUsageDay,
     EnergyUsageResponse,
     EnergyUsageTotal,
@@ -80,7 +95,6 @@ from nwp500.models import (
     MonthlyEnergyData,
     MqttCommand,
     MqttRequest,
-    TemperatureUnit,
     TOUInfo,
     TOUSchedule,
     fahrenheit_to_half_celsius,
@@ -108,15 +122,28 @@ __all__ = [
     "FirmwareInfo",
     "TOUSchedule",
     "TOUInfo",
-    "DhwOperationSetting",
-    "CurrentOperationMode",
-    "TemperatureUnit",
     "MqttRequest",
     "MqttCommand",
     "EnergyUsageTotal",
     "EnergyUsageDay",
     "MonthlyEnergyData",
     "EnergyUsageResponse",
+    # Enumerations
+    "CommandCode",
+    "CurrentOperationMode",
+    "DhwOperationSetting",
+    "DREvent",
+    "ErrorCode",
+    "FilterChange",
+    "HeatSource",
+    "OnOffFlag",
+    "Operation",
+    "RecirculationMode",
+    "TemperatureType",
+    "TempFormulaType",
+    "TouRateType",
+    "TouWeekType",
+    "UnitType",
     # Conversion utilities
     "fahrenheit_to_half_celsius",
     # Authentication
